@@ -3,7 +3,7 @@ use super::*;
 pub fn gen_bool32() -> TokenStream {
     quote! {
         #[repr(transparent)]
-        #[derive(::std::default::Default, ::std::clone::Clone, ::std::marker::Copy, ::std::cmp::PartialEq, ::std::cmp::Eq, ::std::fmt::Debug)]
+        #[derive(::core::default::Default, ::core::clone::Clone, ::core::marker::Copy, ::core::cmp::PartialEq, ::core::cmp::Eq, ::core::fmt::Debug)]
         pub struct BOOL(pub i32);
 
         unsafe impl ::windows::runtime::Abi for BOOL {
@@ -37,19 +37,19 @@ pub fn gen_bool32() -> TokenStream {
             }
         }
 
-        impl ::std::convert::From<BOOL> for bool {
+        impl ::core::convert::From<BOOL> for bool {
             fn from(value: BOOL) -> Self {
                 value.as_bool()
             }
         }
 
-        impl ::std::convert::From<&BOOL> for bool {
+        impl ::core::convert::From<&BOOL> for bool {
             fn from(value: &BOOL) -> Self {
                 value.as_bool()
             }
         }
 
-        impl ::std::convert::From<bool> for BOOL {
+        impl ::core::convert::From<bool> for BOOL {
             fn from(value: bool) -> Self {
                 if value {
                     BOOL(1)
@@ -59,25 +59,25 @@ pub fn gen_bool32() -> TokenStream {
             }
         }
 
-        impl ::std::convert::From<&bool> for BOOL {
+        impl ::core::convert::From<&bool> for BOOL {
             fn from(value: &bool) -> Self {
                 (*value).into()
             }
         }
 
-        impl ::std::cmp::PartialEq<bool> for BOOL {
+        impl ::core::cmp::PartialEq<bool> for BOOL {
             fn eq(&self, other: &bool) -> bool {
                 self.as_bool() == *other
             }
         }
 
-        impl ::std::cmp::PartialEq<BOOL> for bool {
+        impl ::core::cmp::PartialEq<BOOL> for bool {
             fn eq(&self, other: &BOOL) -> bool {
                 *self == other.as_bool()
             }
         }
 
-        impl std::ops::Not for BOOL {
+        impl ::core::ops::Not for BOOL {
             type Output = Self;
             fn not(self) -> Self::Output {
                 if self.as_bool() {
