@@ -3,11 +3,11 @@ use super::*;
 pub fn gen_bstr() -> TokenStream {
     quote! {
         #[repr(transparent)]
-        #[derive(::std::cmp::Eq)]
+        #[derive(::core::cmp::Eq)]
         pub struct BSTR(pub *mut u16);
         impl BSTR {
             pub fn new() -> Self {
-                Self(std::ptr::null_mut())
+                Self(core::ptr::null_mut())
             }
 
             pub fn is_empty(&self) -> bool {
@@ -24,7 +24,7 @@ pub fn gen_bstr() -> TokenStream {
 
             pub fn from_wide(value: &[u16]) -> Self {
                 if value.len() == 0 {
-                    return Self(::std::ptr::null_mut());
+                    return Self(::core::ptr::null_mut());
                 }
 
                 unsafe {
@@ -40,93 +40,97 @@ pub fn gen_bstr() -> TokenStream {
                     return &[];
                 }
 
-                unsafe { ::std::slice::from_raw_parts(self.0 as *const u16, self.len()) }
+                unsafe { ::core::slice::from_raw_parts(self.0 as *const u16, self.len()) }
             }
         }
-        impl ::std::clone::Clone for BSTR {
+        impl ::core::clone::Clone for BSTR {
             fn clone(&self) -> Self {
                 Self::from_wide(self.as_wide())
             }
         }
-        impl ::std::convert::From<&str> for BSTR {
+        // TODO: these str traits should work with no_std
+        #[cfg(feature = "std")]
+        impl ::core::convert::From<&str> for BSTR {
             fn from(value: &str) -> Self {
                 let value: ::std::vec::Vec<u16> = value.encode_utf16().collect();
                 Self::from_wide(&value)
             }
         }
-
-        impl ::std::convert::From<::std::string::String> for BSTR {
+        #[cfg(feature = "std")]
+        impl ::core::convert::From<::std::string::String> for BSTR {
             fn from(value: ::std::string::String) -> Self {
                 value.as_str().into()
             }
         }
-
-        impl  ::std::convert::From<&::std::string::String> for BSTR {
+        #[cfg(feature = "std")]
+        impl  ::core::convert::From<&::std::string::String> for BSTR {
             fn from(value: &::std::string::String) -> Self {
                 value.as_str().into()
             }
         }
-        impl<'a> ::std::convert::TryFrom<&'a BSTR> for ::std::string::String {
+        #[cfg(feature = "std")]
+        impl<'a> ::core::convert::TryFrom<&'a BSTR> for ::std::string::String {
             type Error = ::std::string::FromUtf16Error;
 
-            fn try_from(value: &BSTR) -> ::std::result::Result<Self, Self::Error> {
+            fn try_from(value: &BSTR) -> ::core::result::Result<Self, Self::Error> {
                 ::std::string::String::from_utf16(value.as_wide())
             }
         }
-
-        impl ::std::convert::TryFrom<BSTR> for ::std::string::String {
+        #[cfg(feature = "std")]
+        impl ::core::convert::TryFrom<BSTR> for ::std::string::String {
             type Error = ::std::string::FromUtf16Error;
 
-            fn try_from(value: BSTR) -> ::std::result::Result<Self, Self::Error> {
+            fn try_from(value: BSTR) -> ::core::result::Result<Self, Self::Error> {
                 ::std::string::String::try_from(&value)
             }
         }
-        impl ::std::default::Default for BSTR {
+        impl ::core::default::Default for BSTR {
             fn default() -> Self {
-                Self(::std::ptr::null_mut())
+                Self(::core::ptr::null_mut())
             }
         }
-        impl ::std::fmt::Display for BSTR {
-            fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
-                use ::std::fmt::Write;
-                for c in ::std::char::decode_utf16(self.as_wide().iter().cloned()) {
-                    f.write_char(c.map_err(|_| ::std::fmt::Error)?)?
+        impl ::core::fmt::Display for BSTR {
+            fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+                use ::core::fmt::Write;
+                for c in ::core::char::decode_utf16(self.as_wide().iter().cloned()) {
+                    f.write_char(c.map_err(|_| ::core::fmt::Error)?)?
                 }
                 Ok(())
             }
         }
-        impl ::std::fmt::Debug for BSTR {
-            fn fmt(&self, f: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
-                ::std::write!(f, "{}", self)
+        impl ::core::fmt::Debug for BSTR {
+            fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+                ::core::write!(f, "{}", self)
             }
         }
-        impl ::std::cmp::PartialEq for BSTR {
+        impl ::core::cmp::PartialEq for BSTR {
             fn eq(&self, other: &Self) -> bool {
                 self.as_wide() == other.as_wide()
             }
         }
-        impl ::std::cmp::PartialEq<::std::string::String> for BSTR {
+        #[cfg(feature = "std")]
+        impl ::core::cmp::PartialEq<::std::string::String> for BSTR {
             fn eq(&self, other: &::std::string::String) -> bool {
                 self == other.as_str()
             }
         }
-        impl ::std::cmp::PartialEq<str> for BSTR {
+        impl ::core::cmp::PartialEq<str> for BSTR {
             fn eq(&self, other: &str) -> bool {
                 self == other
             }
         }
-        impl ::std::cmp::PartialEq<&str> for BSTR {
+        impl ::core::cmp::PartialEq<&str> for BSTR {
             fn eq(&self, other: &&str) -> bool {
                 self.as_wide().iter().copied().eq(other.encode_utf16())
             }
         }
 
-        impl ::std::cmp::PartialEq<BSTR> for &str {
+        impl ::core::cmp::PartialEq<BSTR> for &str {
             fn eq(&self, other: &BSTR) -> bool {
                 other == self
             }
         }
-        impl ::std::ops::Drop for BSTR {
+        impl ::core::ops::Drop for BSTR {
             fn drop(&mut self) {
                 if !self.0.is_null() {
                     unsafe { SysFreeString(self as &Self) }
@@ -134,15 +138,17 @@ pub fn gen_bstr() -> TokenStream {
             }
         }
         unsafe impl ::windows::runtime::Abi for BSTR {
-            type Abi = ::std::mem::ManuallyDrop<Self>;
+            type Abi = ::core::mem::ManuallyDrop<Self>;
         }
         pub type BSTR_abi = *mut u16;
+        #[cfg(feature = "std")]
         impl<'a> ::windows::runtime::IntoParam<'a, BSTR> for &str {
             fn into_param(self) -> ::windows::runtime::Param<'a, BSTR> {
                 ::windows::runtime::Param::Owned(self.into())
             }
         }
-        impl<'a> ::windows::runtime::IntoParam<'a, BSTR> for String {
+        #[cfg(feature = "std")]
+        impl<'a> ::windows::runtime::IntoParam<'a, BSTR> for ::std::string::String {
             fn into_param(self) -> ::windows::runtime::Param<'a, BSTR> {
                 ::windows::runtime::Param::Owned(self.into())
             }
